<?php

namespace App\Http\Controllers\Auth;

use Illuminate\Http\Request;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;

use App\Models\User;

use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Mail;
use Carbon\Carbon;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    // protected function create(array $data)
    // {
    //     return User::create([
    //         'name' => $data['name'],
    //         'email' => $data['email'],
    //         'password' => Hash::make($data['password']),
    //     ]);
    // }
    public function store(Request $req)
    {
        // dd($req);
        $this->validate($req, [
            'fname' => 'required',
            'lname' => 'required',
            'email' => 'required',
            'password' => 'required',
        ]);
        $users=new User();
        $users->name=$req->fname.''.$req->lname;
        $users->email=$req->email;
        $users->password=Hash::make($req->password);
        $users->save();
        return redirect()->back()->with('status',"Account created Successfully");
    }

    public function email(Request $request)
    {
        $request->validate([
            'email'=>'required|email'
        ]);

        $token = \Str::random(64);
        \DB::table('password_resets')->insert([
            'email'=>$request->email,
            'token'=>$token,
            'created_at'=>Carbon::now(),
        ]);




        $action_link = route('reset.password.form',['token'=>$token,'email'=>$request->email]);
        $body = "We are received a request to reset the password for <b>Wherever Platform</b> account associated with ".$request->email.". You can reset your password by clicking the link below";

       \Mail::send('auth.email-forgot',['action_link'=>$action_link,'body'=>$body], function($message) use ($request){
             $message->from('hala.rahim@azimutbs.com','Wherever platform');
             $message->to($request->email,'Wherever platform')
                     ->subject('Reset Password');
       });

       return back()->with('success', 'We have e-mailed your password reset link!');
    }

    public function showResetForm(Request $request, $token = null){
        return view('auth.passwords.reset')->with(['token'=>$token,'email'=>$request->email]);
    }

    public function resetPassword(Request $request){
        // dd($request);

        $request->validate([
            'email'=>'required|email',
            'password'=>'required|min:5|confirmed',
            // 'password_confirmation'=>'required',
        ]);
        // dd($request->user);
            // dd($request->user);
            $check_token = \DB::table('password_resets')->where([
                'email'=>$request->email,
                'token'=>$request->token,
            ])->first();
            // dd($check_token);

            if(!$check_token){
                dd($request);
                return back()->withInput()->with('fail', 'Invalid token');
            }else{

                User::where('email', $request->email)->update([
                    'password'=>\Hash::make($request->password)
                ]);

                \DB::table('password_resets')->where([
                    'email'=>$request->email,
                ])->delete();
                // $action_link = route('reset.password.form',['token'=>$token,'email'=>$request->email]);
                $body = "";

                \Mail::send('auth.email-success',['body'=>$body], function($message) use ($request){
                        $message->from('hala.rahim@azimutbs.com','Wherever platform');
                        $message->to($request->email,'Wherever platform')
                                ->subject('Reset Password');
                });

                return redirect()->route('home')->with('info', 'Your password has been changed! You can login with new password')->with('verifiedEmail', $request->email);
            }

    }
}
