<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Auth;

use App\Models\Omra;
use App\Models\Hotel;
use App\Models\Photo;
use App\Models\DemandeOmra;

class OmraController extends Controller
{
    public function index()
    {
        $omras = Omra::with('hotel')->get();
        // dd($omras);
        $hotels = Hotel::get();
        return view('omra.index',['omras' => $omras,'hotels' => $hotels]);
    }
    public function index_home()
    {
        $omras = Omra::with('hotel')->get();
        $hotels = Hotel::get();
        return view('services.omra',['omras' => $omras,'hotels' => $hotels]);
    }

    public function store(Request $req)
    {
        // dd($req);
        $omra = new Omra();
        $omra->d_debut = $req->d_debut;
        $omra->d_fin = $req->d_fin;
        $omra->t_depart = $req->t_depart;
        $omra->t_fin = $req->t_fin;
        $omra->hotel_id = $req->hotel;
        $omra->chambre = $req->chambre;
        $omra->description = $req->description;
        $omra->price = $req->prix;
        if($req->hasfile('photo')){

            $photofile = $req->file('photo');
            $photofilename = time().'.'.$photofile->getClientOriginalExtension();
            $photofile->storeAs('public/assets/omra',$photofilename);
            $omra->photo = $photofilename;
        }

        $omra->save();
        return redirect()->back()->with('status', "Omra Added Successfully");
    }

    public function destroy($id)
    {
        $omra= Omra::findOrFail($id);
        $omra ->delete();
        return redirect()->back();
    }

    public function update(Request $req, $id)
    {
        // dd($req);
        $omra = Omra::findOrFail($id);
        $omra->d_debut = $req->d_debut;
        $omra->d_fin = $req->d_fin;
        $omra->t_depart = $req->t_depart;
        $omra->t_fin = $req->t_fin;
        $omra->hotel_id = $req->hotel;
        $omra->chambre = $req->chambre;
        $omra->price = $req->prix;
        if($req->hasfile('photo'))
        {
            $path = 'public/assets/omra'.$omra->photo;
            if(File::exists($path) )
            {
                File::delete($path);
            }
            $file = $req->file('photo');
            $filename = time().'.'.$file->getClientOriginalExtension();
            $file->storeAs('public/assets/omra',$filename);
            $omra->photo = $filename;
            // $salon->image = $filename;
        }
        $omra->save();
        return redirect()->back()->with('status', "Omra Updated Successfully");
    }


    public function details($id)
    {
        $omra = Omra::with('hotel')->findOrFail($id);
        $photos_hotels = Photo::where('id_hotel', $omra->hotel_id)->where('type',"hotel")->get();
        $photos_rooms = Photo::where('id_hotel', $omra->hotel_id)->where('type',"room")->get();
        return view('services.omra_details',['omra' => $omra, 'photos_hotels' => $photos_hotels, 'photos_rooms' => $photos_rooms]);
    }

    public function detailsOmraAdmin($id)
    {
        $omra = Omra::with('hotel')->findOrFail($id);
        $omra_demandes = DemandeOmra::with(['user'])->where('omra_id',$id)->get();
        $photos_hotels = Photo::where('id_hotel', $omra->hotel_id)->where('type',"hotel")->get();
        $photos_rooms = Photo::where('id_hotel', $omra->hotel_id)->where('type',"room")->get();
        // dd($photos);
        return view('omra.omra_details',['omra' => $omra, 'omra_demandes' => $omra_demandes, 'photos_hotels' => $photos_hotels, 'photos_rooms' => $photos_rooms]);
    }



    public function open($id)
    {
        $demande = Omra::findOrFail($id);
        $demande->status = 'Open';
        $demande->save();
        return redirect()->back();
    }
    public function close($id)
    {
        $demande = Omra::findOrFail($id);
        $demande->status = 'Close';
        $demande->save();
        return redirect()->back();
    }

}
