<?php

use Illuminate\Support\Facades\Route;

use App\Http\Controllers\PageController;
use App\Http\Controllers\OmraController;
use App\Http\Controllers\HotelController;
use App\Http\Controllers\DemandeOmraController;

use App\Http\Controllers\Auth\RegisterController;
use App\Http\Controllers\Auth\LoginController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::middleware('locale')->prefix('{lang?}')->group(function() {
    Route::controller(RegisterController::class)
    ->group(function(){
        Route::post('/store', 'store')->name('register.store');
        Route::post('/email', 'email')->name('password.email');
        Route::get('/password/reset/{token}','showResetForm')->name('reset.password.form');
        Route::post('/password/reset','resetPassword')->name('reset.password');
    });
    Route::controller(LoginController::class)
        ->group(function(){
            Route::post('/loginHome', 'loginHome')->name('loginHome');
            Route::get('/login', 'loginHome')->name('login');
        });
    Route::get('/logout', [LoginController::class, 'logout'])->name('auth.logout');




    Route::get('/visa', function () {
        return view('services.visa');
    });

    Route::get('/dashboard', function () {
        return view('layouts.dashboard');
    })->name('dashboard')->middleware('admin');

    Route::get('/dashboard-user', function () {
        return view('layouts.dashboard');
    })->name('dashboard-user')->middleware('user');



    Route::controller(DemandeOmraController::class)
        ->prefix('demande/user')
        ->middleware('user')
        ->group(function(){
            Route::get('/list_demande_user', 'list_demande_user')->name('omra.list_demande_user');
            Route::get('/demande-details/{id}', 'demandeDetails')->name('omra.demandeDetails');
            Route::post('/demande-update/{id}', 'updateDemande')->name('omra.updateDemande');
        });
    Route::controller(DemandeOmraController::class)
        ->prefix('demande')
        ->middleware('auth')
        ->group(function(){
            Route::get('/demande-details/{id}', 'demandeDetails')->name('omra.demandeDetails');

        });
    Route::controller(DemandeOmraController::class)
        ->prefix('demande/admin')
        ->middleware('admin')
        ->group(function(){
            Route::get('/list_demande', 'list_demande')->name('omra.list_demande');
            Route::post('/omra-demande/{id}', 'demande')->name('omra.demande');
            Route::get('/omra-approve/{id}', 'approve')->name('omra.approve');
            Route::post('/omra-disapprove/{id}', 'disapprove')->name('omra.disapprove');

        });
    Route::controller(OmraController::class)
        ->prefix('omra/admin')
        ->middleware('admin')
        ->group(function(){
            Route::get('/', 'index')->name('omra.index');
            Route::post('/store', 'store')->name('omra.store');
            Route::post('/update/{id}', 'update')->name('omra.update');
            Route::get('/destroy/{id}', 'destroy')->name('omra.destroy');

            Route::get('/admin-omra-details/{id}', 'detailsOmraAdmin')->name('admin.omra.details');
            // Route::get('/demande-details/{id}', 'demandeDetails')->name('omra.demandeDetails');
            Route::get('/omra-open{id}', 'open')->name('omra.open');
            Route::post('/omra-close/{id}', 'close')->name('omra.close');
        });
    Route::controller(OmraController::class)
        ->prefix('omra')
        ->group(function(){
            Route::get('/omra-service', 'index_home')->name('omra.index_home');
            Route::get('/omra-details/{id}', 'details')->name('omra.details');
        });
    Route::get('/',[PageController::class,'index_home'])->name('home');
    Route::controller(PageController::class)
        ->prefix('page')
        ->middleware('admin')
        ->group(function(){
            Route::get('/index', 'index')->name('index');
            Route::get('/', 'index_home')->name('index_home');
            Route::post('/store', 'store')->name('video.store');
            Route::get('/destroy/{id}', 'destroy')->name('video.destroy');
        });

    Route::controller(HotelController::class)
        ->prefix('hotel/admin')
        ->middleware('admin')
        ->group(function(){
            Route::get('/', 'index')->name('hotel.index');
            Route::post('/store', 'store')->name('hotel.store');
            Route::post('/update/{id}', 'update')->name('hotel.update');
            Route::get('/destroy/{id}', 'destroy')->name('hotel.destroy');
        });
});

// Auth::routes();

